@@ -10,20 +10,21 @@ def init():
         line = line.strip('\r\n')
         sid, name, phone = line.split()
         model = Shop()
-        model.sid = sid
+        # model.sid = sid
         model.name = name
         model.phone = phone
         model.save()
+        print(model.sid)
     fp.close()
 
 
 if __name__ == '__main__':
-    Database().connect(**db)
-
-    # one = Shop.find().where(sid='s-n-1').one()
-    # one.name = 'shop-name-x'
-    # one.save()
-    # print(one)
-
-    Shop.find().where(sid='s-n-1').update(sid='s-n-x')
+    Database.connect(**db)
 
+    # # one = Shop.find().where(sid='s-n-1').one()
+    # # one.name = 'shop-name-x'
+    # # one.save()
+    # # print(one)
+    #
+    # Shop.find().where(sid='s-n-1').update(sid='s-n-x')
+    init()
